==> jc-1.4.0.tar.gz: soot/jimple/toolkits/invoke/StaticMethodBinder.h <==
// public class soot.jimple.toolkits.invoke.StaticMethodBinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 700f26d7f072e51a soot_jimple_toolkits_invoke_StaticMethodBinder

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_
#define _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$methodUsesThis$e15b38cc1090722d(_jc_env *, struct _jc_soot_SootMethod$object *);
extern struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$v$3cf2d8ae2e7cccf3(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods	soot_jimple_toolkits_invoke_StaticMethodBinder;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs {
    _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs	soot_jimple_toolkits_invoke_StaticMethodBinder;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs	soot_jimple_toolkits_invoke_StaticMethodBinder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object {
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_StaticMethodBinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/invoke/StaticMethodBinder.h <==
// public class soot.jimple.toolkits.invoke.StaticMethodBinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 700f26d7f072e51a soot_jimple_toolkits_invoke_StaticMethodBinder

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_
#define _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object;

typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable;
typedef const struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method_info$internalTransform$b44b61d0d9f22a06;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$methodUsesThis$e15b38cc1090722d(_jc_env *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$method$v$3cf2d8ae2e7cccf3(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods {
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vmethods	soot_jimple_toolkits_invoke_StaticMethodBinder;
};

// Vtype
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs {
    _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_refs	soot_jimple_toolkits_invoke_StaticMethodBinder;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$sub_nonrefs	soot_jimple_toolkits_invoke_StaticMethodBinder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$object {
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype	*vtype;
	_jc_soot_jimple_toolkits_invoke_StaticMethodBinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$vtype _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_invoke_StaticMethodBinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_invoke_StaticMethodBinder$class_object;

#endif	/* _JC_soot_jimple_toolkits_invoke_StaticMethodBinder_H_ */
